@@ -366,14 +366,20 @@ class TestTranslatorEndToEnd(AbstractTestTranslator):
                 "function_with_disabled_deployment_preference",
                 "function_with_disabled_traffic_hook",
                 "function_with_deployment_preference",
+                "function_with_deployment_preference_condition_with_passthrough",
+                "function_with_deployment_preference_condition_without_passthrough",
                 "function_with_deployment_preference_all_parameters",
                 "function_with_deployment_preference_from_parameters",
                 "function_with_deployment_preference_multiple_combinations",
                 "function_with_deployment_preference_alarms_intrinsic_if",
+                "function_with_deployment_preference_multiple_combinations_conditions_with_passthrough",
+                "function_with_deployment_preference_multiple_combinations_conditions_without_passthrough",
+                "function_with_deployment_preference_passthrough_condition_with_supported_intrinsics",
                 "function_with_alias_and_event_sources",
                 "function_with_resource_refs",
                 "function_with_deployment_and_custom_role",
-                "function_with_deployment_no_service_role",
+                "function_with_deployment_no_service_role_with_passthrough",
+                "function_with_deployment_no_service_role_without_passthrough",
                 "function_with_global_layers",
                 "function_with_layers",
                 "function_with_many_layers",
@@ -408,6 +414,7 @@ class TestTranslatorEndToEnd(AbstractTestTranslator):
                 "api_with_auth_and_conditions_all_max",
                 "api_with_apikey_default_override",
                 "api_with_apikey_required",
+                "api_with_apikey_source",
                 "api_with_path_parameters",
                 "function_with_event_source_mapping",
                 "function_with_event_dest",
@@ -472,6 +479,7 @@ class TestTranslatorEndToEnd(AbstractTestTranslator):
                 "api_rest_paths_with_if_condition_openapi_no_value_then_case",
                 "api_rest_paths_with_if_condition_openapi_no_value_else_case",
                 "function_with_function_url_config",
+                "function_with_function_url_config_conditions",
                 "function_with_function_url_config_with_intrinsics",
                 "function_with_function_url_config_with_iam_authorization_type",
                 "function_with_function_url_config_without_cors_config",
@@ -530,10 +538,15 @@ class TestTranslatorEndToEnd(AbstractTestTranslator):
                 "http_api_explicit_stage",
                 "http_api_def_uri",
                 "explicit_http_api",
+                "http_api_custom_iam_auth",
                 "http_api_with_cors",
                 "http_api_description",
+                "http_api_global_iam_auth_enabled_with_existing_conflicting_authorizer",
+                "http_api_global_iam_auth_enabled",
                 "http_api_lambda_auth",
                 "http_api_lambda_auth_full",
+                "http_api_local_iam_auth_enabled_with_existing_conflicting_authorizer",
+                "http_api_local_iam_auth_enabled",
                 "http_api_multiple_authorizers",
             ],
             [
